Uses a jitter-and-retry strategy when the input matrix is not quite
positive-definite. Falls back to Matrix::nearPD() if available, and
errors rather than passing a non-lower-triangular factor to Stan.
Uses a jitter-and-retry strategy when the input matrix is not quite
positive-definite. Falls back to Matrix::nearPD() if available, and
errors rather than passing a non-lower-triangular factor to Stan.